@@ -19,6 +19,7 @@ use IO::Tee;
 use Set::Intersection;
 use List::Compare;
 use Data::Dumper;
+use POSIX;
 #$Data::Dumper::Indent = 0;
 #$Data::Dumper::Useqq  = 1;
 #$Data::Dumper::Terse  = 1;
@@ -34,15 +35,14 @@ no warnings;
 
 use Sim::OPT::Morph;
 use Sim::OPT::Sim;
-use Sim::OPT::Retrieve;
 use Sim::OPT::Report;
 use Sim::OPT::Descend;
 use Sim::OPT::Takechance;
 use Sim::OPT::Parcoord3d;
 
-our @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
+our @ISA = qw( Exporter ); # our @adamkISA = qw(Exporter);
 #%EXPORT_TAGS = ( DEFAULT => [qw( &opt &prepare )]); # our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
-#@EXPORT_OK   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+#@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw( 
 opt takechance
@@ -54,14 +54,14 @@ getitem getline getlines getcase getstepsvar tell wash flattenbox enrichbox filt
 $configfile $mypath $exeonfiles $generatechance $file $preventsim $fileconfig $outfile $toshell $report 
 $simnetwork @themereports @simtitles @reporttitles @simdata @retrievedata 
 @keepcolumns @weights @weightsaim @varthemes_report @varthemes_variations @varthemes_steps 
-@rankdata @rankcolumn @reporttempsdata @reportcomfortdata @reportradiationenteringdata 
+@rankdata @rankcolumn @reporttempsdata @reportcomfortdata @reportdata 
 @report_loadsortemps @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns 
 @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns %vals 
-@sweeps @mediumiters @varinumbers @caseseed @chanceseed @chancedata $dimchance $tee @pars_tocheck 
+@sweeps @mediumiters @varinumbers @caseseed @chanceseed @chancedata $dimchance $tee @pars_tocheck retrieve
 $target 
-); # our @EXPORT = qw( );
+);
 
-$VERSION = '0.40.14'; # our $VERSION = '';
+$VERSION = '0.41.1'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT it a tool for detailed metadesign. It manages parametric explorations through the ESP-r building performance simulation platform and performs optimization by block coordinate descent.';
 
 #################################################################################
@@ -387,19 +387,18 @@ sub calcmediumiters
 	foreach ( @varinumbers )
 	{
 		my $countblock = 0;
-		foreach (keys %$_)
+		foreach ( keys %$_ )
 		{
 			#say "inner dump (\$_): " . dump ($_);
 			#say "dumpalias (\$varinumbers[\$countcase]{\$_}): " . dump ($varinumbers[$countcase]{$_});
-			unless (defined $mediumiters[$countcase]{$_})
+			unless ( defined $mediumiters[$countcase]{$_} )
 			{
-				#say "dump (\$mediumiters[\$countcase][\$countblock]{\$_}): " . dump ($mediumiters[$countcase][$countblock]{$_}); 
-				$mediumiters[$countcase]{$_} = ( round($varinumbers[$countcase]{$_}/2) );
+				$mediumiters[$countcase]{$_} = ( ceil( $varinumbers[$countcase]{$_} / 2 ) );
 			}
 		}
 		$countcase++;
 	} # TO BE CALLED WITH: calcmediumiters(@varinumbers)
-	return (@mediumiters);
+	return ( @mediumiters );
 }
 	
 sub getitersnum
@@ -646,7 +645,7 @@ sub integratebox
 		my @elts = @{ $eltref }; #say "\@elts " . dump(@elts);
 		my $target = $elts[0]; #say "\$target " . dump($target);
 		my $origin = $elts[3]; #say "\$origin " . dump($origin);
-		my @result = extractcase( $target, \%carrier ); say "\@result: " . dump(@result);
+		my @result = extractcase( $target, \%carrier ); #say "\@result: " . dump(@result);
 		my $righttarget = $result[0];
 		my @result = extractcase( $origin, \%carrier );
 		my $rightorigin = $result[0];
@@ -727,12 +726,12 @@ sub callcase # IT PROCESSES THE CASES.
 	#	$dirfiles{descendcases}, $dirfiles{descendstruct} );
 	#}
 	
-	open ( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-	open ( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
+	open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
+	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
 	
 	#if ( ($countcase > 0) or ($countblock > 0) )
 	#{
-		say $tee "#Called for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
+		#say $tee "#Called for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	#}
 
 	#my @taken = extractcase("$toitem", \%mids); #say "------->taken: " . dump(@taken);
@@ -743,7 +742,7 @@ sub callcase # IT PROCESSES THE CASES.
 				countcase => $countcase, countblock => $countblock,
 				miditers => \@miditers,  winneritems => \@winneritems, 
 				dirfiles => \%dirfiles, uplift => \@uplift
-			}; #say $tee "#\n\dumpCASE(\$casedata): " . dump($casedata) . "\n\n";
+			};
 	#say $tee "IN OPT.pm, \$casedata: " . dump($casedata); 
 	callblocks( $casedata );
 	if ( $countblock != 0 ) { return($casedata); }
@@ -769,14 +768,15 @@ sub callblocks # IT CALLS THE SEARCH ON BLOCKS.
 	my %varnums = getcase(\@varinumbers, $countcase); #say $tee "dumpININ---(\%varnums): " . dump(%varnums); 
 	my %mids = getcase(\@miditers, $countcase); #say $tee "dumpININ---(\%mids): " . dump(%mids); 
 	#eval($getfly);
-	say $tee "#Called for a new block for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
-	say $tee "#Calling to define new files for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
+	#say $tee "#Called for a new block for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
+	#say $tee "#Calling to define new files for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	my $blockdata = 
 	{ 
 		countcase => $countcase, countblock => $countblock,
 		miditers => \@miditers,  winneritems => \@winneritems, 
 		dirfiles => \%dirfiles, uplift => \@uplift, 
-	}; #say $tee "\ndumpBLOCK(\$blockdata): " . dump($blockdata) . "\n\n";
+	}; 
+	#say $tee "\ndumpBLOCK(\$blockdata): " . dump($blockdata) . "\n\n";
 	deffiles( $blockdata );
 }
 	
@@ -801,7 +801,7 @@ sub deffiles # IT DEFINED THE FILES TO BE CALLED.
 	my %mids = getcase(\@miditers, $countcase); #say $tee  "#dumpININ---(\%mids): " . dump(%mids);
 	#eval($getfly);
 	
-	say $tee "#Called to define new files for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
+	#say $tee "#Called to define new files for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	
 	my $rootitem = "$file" . "_"; #say "\$rootitem $rootitem";
 	my (@basket, @box);
@@ -833,7 +833,7 @@ sub deffiles # IT DEFINED THE FILES TO BE CALLED.
 	my @integrated = integratebox(\@flattened, \%mids, $file); #say $tee  "#\@integrated " . dump(@integrated) . ", " . scalar(@integrated);
 	my @finalbox = filterbox(@integrated); #say $tee  "#\@finalbox " . dump(@finalbox) . ", " . scalar(@finalbox); 
 	
-	say $tee "#Calling to instruct the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
+	#say $tee "#Calling to instruct the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	my $datatowork = 
 	{ 
 		countcase => $countcase, countblock => $countblock,
@@ -841,7 +841,7 @@ sub deffiles # IT DEFINED THE FILES TO BE CALLED.
 		dirfiles => \%dirfiles, uplift => \@uplift, 
 		basket => \@finalbox   
 	} ;
-	# say $tee "\ndumper-datatowork: " . dump($datatowork) . "\n\n";
+	#say $tee "\ndumper-datatowork: " . dump($datatowork) . "\n\n";
 	setlaunch( $datatowork );
 }	
 
@@ -867,7 +867,7 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 	my %mids = getcase(\@miditers, $countcase); #say "dumpININ---(\%mids): " . dump(%mids); 
 	#eval($getfly);
 	
-	say $tee "#Called to instruct the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
+	#say $tee "#Called to instruct the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	
 	my ( @instances, %carrier);
 	#if ($countblock == 0)
@@ -901,9 +901,9 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 			origin => $origin
 		} );
 	} 
-	say $tee "#Calling to execute the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
+	#say $tee "#Calling to execute the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	
-	say $tee "\ninstances: " . dump(@instances). "\n\n"; ### ZZZ
+	#say $tee "\ninstances: " . dump(@instances). "\n\n"; ### ZZZ
 	exe( @instances ); # IT HAS TO BE CALLED WITH: setlaunch(@datatowork). @datatowork ARE CONSTITUTED BY AN ARRAY OF: ( [ \@blocks, \%varnums, \%bases, $name, $countcase, \@blockelts, $countblock ], ... )
 }	
 		
@@ -917,12 +917,12 @@ sub exe
 	my $countblock = $d{countblock}; #say "dump(\$countblock): " . dump($countblock);
 	my %dirfiles = %{ $d{ dirfiles } };
 	
-	say $tee "#Called to execute the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
+	say $tee "#Executing new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	#say $tee "Do what:" . dump(%dowhat);
 	
 	if ( $dowhat{morph} eq "y" ) 
 	{ 
-		say $tee "#Calling morphing operations for case " . ($countcase +1) . "block " . ($countblock + 1) . ".";
+		say $tee "#Calling morphing operations for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 		#say $tee "WITH: \@instances " . dump(@instances) . ", \$countcase $countcase, \$countblock $countblock, \%dirfiles " . dump(%dirfiles) . ".";
 		my @result = Sim::OPT::Morph::morph( 
 		{ 
@@ -935,7 +935,7 @@ sub exe
 
 	if ( $dowhat{simulate} eq "y" )
 	{ 
-		say $tee "#Calling simulations for case " . ($countcase +1) . "block " . ($countblock + 1) . ".";
+		say $tee "#Calling simulations for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 		my @result = Sim::OPT::Sim::sim( 
 		{ 
 			instances => \@instances, countcase => $countcase, countblock => $countblock, 
@@ -947,19 +947,20 @@ sub exe
 	
 	if ( $dowhat{retrieve} eq "y" )
 	{ 
-		say $tee "#Calling retrieval of results for case " . ($countcase +1) . "block " . ($countblock + 1) . ".";
-		my @result = Sim::OPT::Retrieve::retrieve( 
+		say $tee "#Calling retrieval of results for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
+		my @result = Sim::OPT::Report::retrieve( 
 		{ 
 			instances => \@instances, countcase => $countcase, countblock => $countblock, 
 			dirfiles => \%dirfiles
 		} );
 		$dirfiles{retcases} = $result[0]; #say $tee "\$dirfiles{retcases} : " . dump( $dirfiles{retcases} );
 		$dirfiles{retstruct} = $result[1];
+		$dirfiles{notecases} = $result[2];
 	}
 	
 	if ( $dowhat{report} eq "y" )
 	{ 
-		say $tee "#Calling the reporting of results for case " . ($countcase +1) . "block " . ($countblock + 1) . ".";
+		say $tee "#Calling reporting of results for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 		my @result = Sim::OPT::Report::report( 
 		{ 
 			instances => \@instances, countcase => $countcase, countblock => $countblock, 
@@ -974,7 +975,7 @@ sub exe
 	
 	if ( $dowhat{descend} eq "y" )
 	{ 
-		say $tee "#Calling the descent in case " . ($countcase +1) . "block " . ($countblock + 1) . ".";
+		say $tee "#Calling descent in case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 		my @result = Sim::OPT::Descend::descend( 
 		{ 
 			instances => \@instances, countcase => $countcase, countblock => $countblock, 
@@ -1016,7 +1017,7 @@ sub start
 {
 ###########################################
 print "THIS IS OPT.
-Copyright by Gian Luca Brunetti and Politecnico di Milano, 2008-14.
+Copyright by Gian Luca Brunetti and Politecnico di Milano, 2008-15.
 { DAStU Department, Polytechnic of Milan }
 
 .  .  .  .  .  .  .  .  .  .  .  .  .
@@ -1051,8 +1052,8 @@ sub opt
 
 	print "\nNow in Sim::OPT.\n";
 		
-	open ( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-	open ( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
+	open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
+	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
 		
 	#unless (-e "$mypath") 
 	#{ 
@@ -1066,6 +1067,8 @@ sub opt
 	#	print TOSHELL "mkdir $mypath\n\n"; 
 	#}
 	
+	if ( not ( $target ) ) { $target = "opt"; }
+	
 	#####################################################################################
 	# INSTRUCTIONS THAT LAUNCH OPT AT EACH SWEEP (SUBSPACE SEARCH) CYCLE
 	
@@ -1073,12 +1076,12 @@ sub opt
 	{
 		if ( ( @sweepseed ) and ( @chancedata ) ) # IF THIS VALUE IS DEFINED. TO BE FIXED. ZZZ
 		{
-			my $yield = fromsweep_toopt(@sweeps); say $tee "Dumper(\$yield): " . Dumper($yield);
-			my @caseseed = @{ $yield[0] }; say $tee "Dumper(\@caseseed): " . Dumper(@caseseed);
-			my @chanceseed = @{ $yield[1] }; say $tee "Dumper(\@chanceseed): " . Dumper(@chanceseed);
+			my $yield = fromsweep_toopt( @sweeps ); say $tee "Dumper(\$yield): " . Dumper($yield);
+			@caseseed = @{ $yield[0] }; say $tee "Dumper(\@caseseed): " . Dumper(@caseseed);
+			@chanceseed = @{ $yield[1] }; say $tee "Dumper(\@chanceseed): " . Dumper(@chanceseed);
 		}
 	}
-	
+			
 	#say $tee "\@chanceseedINI: " . Dumper(@chanceseed); # GLOBAL ZZZ
 	#say $tee "\@caseseedINI: " . Dumper(@caseseed); # GLOBAL ZZZ
 	@chanceseed = convchanceseed(@chanceseed); #say $tee "convchanceseed Dumper(\@chanceseed): " . Dumper(@chanceseed); # GLOBAL ZZZ	
@@ -1093,7 +1096,7 @@ sub opt
 		@sweeps_ = @{ $obt[0] };
 		@caseseed_ = @{ $obt[1] };
 		@chanceseed_ = @{ $obt[2] };
-		open (MESSAGE, ">./search_structure_that_may_be_adopted.txt");
+		open( MESSAGE, ">./search_structure_that_may_be_adopted.txt" );
 		say MESSAGE "\@sweeps_ " . Dumper(@sweeps_);
 		say MESSAGE "\THESE VALUES OF \@sweeps IS EQUIVALENT TO THE FOLLOWING VALUES OF \@caseseed AND \@chanceseed: ";
 		say MESSAGE "\n\@caseseed " . Dumper(@caseseed_);
@@ -1110,9 +1113,9 @@ sub opt
 		#my  $itersnum = $varinumbers[$countcase]{$varinumber}; say "\$itersnum: $itersnum"; 
 		#say "dump(\@varinumbers), " . dump(@varinumbers); #say "dumpBEFORE(\@miditers), " . dump(@miditers);
 	
-		calcoverlaps(@sweeps); # PRODUCES @calcoverlaps WHICH IS globsAL. ZZZ
-		say "VARINUMBERS: " . dump ( @varinumbers );
-		@mediumiters = calcmediumiters( @varinumbers ); say $tee "BEGINNING dump!(\@mediumiters), " . dump(@mediumiters); # globsALS. ZZZ
+		calcoverlaps( @sweeps ); # PRODUCES @calcoverlaps WHICH IS global. ZZZ
+		say $tee "VARINUMBERS: " . dump ( @varinumbers );
+		@mediumiters = calcmediumiters( @varinumbers ); say $tee "(\@mediumitems): " . dump(@mediumiters); # globsALS. ZZZ
 		#$itersnum = getitersnum($countcase, $varinumber, @varinumbers); #say "\$itersnum OUT = $itersnum";
 		
 		@rootnames = definerootcases(\@sweeps, \@mediumiters); say $tee "BEGINNING \@rootnames " . dump(@rootnames); 
@@ -1120,7 +1123,7 @@ sub opt
 		my $countcase = 0;
 		my $countblock = 0;
 
-		my @winneritems = populatewinners(\@rootnames, $countcase, $countblock); say $tee "BEGINNING \@winneritems " . dump(@winneritems);
+		my @winneritems = populatewinners( \@rootnames, $countcase, $countblock ); say $tee "BEGINNING \@winneritems " . dump(@winneritems);
 		
 		callcase( { countcase => $countcase, rootnames => \@rootnames, countblock => $countblock, 
 		miditers => \@mediumiters,  winneritems => \@winneritems } );
@@ -1152,36 +1155,35 @@ Sim::OPT.
 
 =head1 DESCRIPTION
 
-Sim::OPT is a set of tools for detailed metadesign of buildings. The main module morphs models by propagation of constraints mainly through the ESP-r building performance simulation platform and performs optimization by overlapping block coordinate descent.
+Sim::OPT is a set of tools for detailed metadesign of buildings. Its main components are an optimization module pursuing optimization by overlapping block coordinate descent and a morphing module which morphs building models by propagation of constraints through the ESP-r building performance simulation platform. Other components are retrieval and reporting modules and a module emitting parallel coordinates plots in 3D.
 
-A working knowledge of ESP-r (http://www.esru.strath.ac.uk/Programs/ESP-r.htm) is necessary to use most functionalitues of OPT. ESP-r must be compiled for text (not graphics) to be managed by OPT. It has only been tested on Linux.
+A working knowledge of ESP-r (http://www.esru.strath.ac.uk/Programs/ESP-r.htm) is presently necessary to use most functionalitues of OPT. (ESP-r must be compiled for text (not graphics) to be managed by OPT.)
 
-To install OPT, the command <cpanm Sim::OPT> has to be issued. Perl will install all dependencies. OPT can be loaded through the command <use Sim::OPT> in Perl. For that purpose, the batch file "opt" (which can be found packed in the "optw.tar.gz" file in "example" folder in this distribution) may be copied in a work directory and the command <opt> may be issued. That command will activate the OPT's functions, following the settings specified in a previously prepared configuration file. When launched, OPT will ask the path to that file. Its activity will start after receiving that information. 
+To install OPT, the command <cpanm Sim::OPT> has to be issued. OPT can be loaded through the command <use Sim::OPT> in Perl. For that purpose, the batch file "opt" (which can be found packed in the "optw.tar.gz" file in "example" folder in this distribution) may be copied in a work directory and the command <opt> may be issued. That command will activate the OPT's functions, following the settings specified in a previously prepared configuration file. When launched, OPT will ask the path to that file. Its activity will start after receiving that information. 
 That file must contain a suitable description of the operations to be accomplished pointing to an existing ESP-r model.
 
-In "optw.tar.gz" there is an example of OPT configuration file ("v.pl"). That file may be decompacted and the resulting folder ("optw") may be used as a work folder for OPT, in which the ESP-r models to be worked should reside. The "$mypath" variable in the configuration file must be set to the work directory. An example of configuration file for an earlier version of OPT may be downloaded at http://figshare.com/authors/Gian_luca_Brunetti/624879 .
+In "optw.tar.gz" there is an example of OPT configuration file ("v.pl"). That file may be decompacted and the resulting folder ("optw") may be used as a work folder for OPT, in which the ESP-r models to be worked may reside. The "$mypath" variable in the configuration file must be set to that work directory.
 
-To run OPT without making it launch ESP-r, the setting <$exeonfiles = "n";> should be specified in the configuration file. This may only be aimed to inspect the commands that OPTS would give to ESP-r through the shell. The search obtained would likely be different from that driven by simulation results. If simulations are not launched, the optimal instance  at each subspace search cannot indeed be selected. In its place, the base case will be kept by the program to completion. A sequential block search (Gauss-Seidel method) cannot indeed be run "dry". In the variable "$toshell" the path to the file that will receive the commands in place of the shell can be specified.
+To run OPT without making it launch ESP-r, the setting <$exeonfiles = "n";> should be specified in the configuration file. This may only be aimed to inspect the commands that OPTS would give to ESP-r through the shell. (In the variable "$toshell" the path to the file that will receive the commands in place of the shell can be specified.) This is only useful for testing the morphing instruction contained in a configuration file before launching a real batch of simulations. Note that in that case the search path will be different from that driven by simulation results. If simulations are not launched, the optimal instance  at each subspace search cannot indeed be selected. In its place, the base case will be kept by the program until completion. A sequential block search (Gauss-Seidel method) cannot indeed be run "dry".
 
-If $exeonfiles is set to "y", OPT will give instruction to ESP-r via shell to make it modify the building base model in different copies. Then, if asked, it will run simulations, retrieve the results, extract some information from them and order it as requested.
+If $exeonfiles is set to "y", OPT will give instruction to ESP-r via shell to make it modify the building model in the specified steps. Then, if asked, it will run simulations, retrieve the results, extract some information from them and order it as requested.
 
-Besides an OPT configuration file, configuration files for propagation of constraints may be created. They would give to the morphing operations greater flexibility. Propagation of constraints can regard the geometry of a model, solar shadings, mass/flow network, and/or controls; and also, how those pieces of information affect each other and daylighting. Example of configuration files for propagation of constraints are included in this distribution.
+Besides an OPT configuration file, separate configuration files for propagation of constraints may be created. Those can be useful to give the morphing operations greater flexibility. Propagation of constraints can regard the geometry of a model, solar shadings, mass/flow network, and/or controls; and also, how those pieces of information affect each other and daylighting.
 
-The ESP-r model folders and the result files that will be created in a parametric search will be named as the base building model, numbers and other characters to described an instance. For example, the instance produced in the first iteration for a root model named "model" in a search constituted by 3 morphing phases and 5 iteration steps each will be named "model_1-1_2-1_3-1"; and the last one "model_1-5_2-5_3-5". 
+The ESP-r model folders and the result files that will be created in a parametric search will be named as the base building model, numbers and other characters to described an instance. For example, the instance produced in the first iteration for a root model named "model" in a search constituted by 3 morphing phases and 5 iteration steps each will be named "model_1-1_2-1_3-1"; and the last one "model_1-5_2-5_3-5".
 
-The structure of block searches is described through the variable "@sweeps". Each case is listed inside square brackets. And each search subspace (block) in them is listed inside square brakets, nested in cases. For example: a sequence constituted by two brute force searches, one regarding parameters 1, 2, 3 and the other regarding parameters 1, 4, 5, 7 would be described with: @sweeps = ( [ [ 1, 2, 3 ] ] , [ [ 1, 4, 5, 7 ] ] ). And a block search with the first subspace regarding parameters 1, 2, 3 and the second regarding parameters 3, 4, 5, 6 would be described with: @sweeps = ( [ [ 1, 2, 3 ] , [ 3, 4, 5, 6 ] ] ). 
+The structure of the block searches is described through the variable "@sweeps". Each case is listed inside square brackets. And each search subspace (block) in them is listed inside square brakets, nested in cases. For example: a sequence constituted by two brute force searches, one regarding parameters 1, 2, 3 and the other regarding parameters 1, 4, 5, 7 would be described with: @sweeps = ( [ [ 1, 2, 3 ] ] , [ [ 1, 4, 5, 7 ] ] ). And a block search with the first subspace regarding parameters 1, 2, 3 and the second regarding parameters 3, 4, 5, 6 would be described with: @sweeps = ( [ [ 1, 2, 3 ] , [ 3, 4, 5, 6 ] ] ). 
 
 The number of iterations to be taken into account for each parameter for each case is specified in the "@varinumbers" variable. To specifiy that the parameters of the last example are to be tried for three values (iterations) each, @varinumbers has to be set to ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3, 5 => 3, 6 => 3 } ).
 
-Some functionalities of OPT are not specific to the ESP-r platform. Those functionalities are mainly contanined in the "Sim::OPT::Takechance" and "Sim::OPT::Parcoord3d" modules. 
+Some functionalities of OPT are not specific to the ESP-r platform. Those functionalities are mainly contanined in the "Sim::OPT::Takechance" and "Sim::OPT::Parcoord3d" modules.
 
 The "Sim::OPT::Takechance" module produces efficient search structures for block coordinate descent given some initialization blocks. A section of the configuration file for "Sim::OPT" is dedicated to the "Sim::OPT::Takechance" module.
 
-The "Sim::OPT::Parcoord3d module receiving as input the data for a bi-dimensional parallel coordinate plot in a cvs file produces as output an Autolisp file that can be used from Autocad or an Intellicad-derived 3D CAD program to obtain a 3D parallel coordinate plot (that can subsequently saved in dwg, dxf or other suitable format). A section of the configuration file for "Sim::OPT" is dedicated to the "Sim::OPT::Parcoord3d" module.
+The "Sim::OPT::Parcoord3d module when receiving as input the data for a bi-dimensional parallel coordinate plot in a cvs file produces as output an Autolisp file that can be used from Autocad or an Intellicad-derived 3D CAD program to obtain a 3D parallel coordinate plot (that may be subsequently saved in dwg, dxf or other formats). A section of the configuration file for "Sim::OPT" is dedicated to the "Sim::OPT::Parcoord3d" module.
 
-OPT is still in an alpha stage. I will not add functionalities to it until it is in beta.
+Gian Luca Brunetti
 
-Gian Luca Brunetti, Politecnico di Milano
 gianluca.brunetti@polimi.it
 
 =head2 EXPORT
