@@ -25,7 +25,6 @@ use feature 'say';
 use Sim::OPT;
 use Sim::OPT::Morph;
 use Sim::OPT::Sim;
-use Sim::OPT::Retrieve;
 use Sim::OPT::Report;
 use Sim::OPT::Takechance;
 
@@ -34,11 +33,11 @@ no warnings;
 
 @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
 #%EXPORT_TAGS = ( DEFAULT => [qw( &opt &prepare )]); # our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
-#@EXPORT_OK   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+#@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.40.0'; # our $VERSION = '';
+$VERSION = '0.41._0'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -73,8 +72,8 @@ sub descend
 	$report = $main::report;
 	$simnetwork = $main::simnetwork;
 	
-	open ( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-	open ( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!";  
+	open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
+	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!";  
 	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
 	say "\nNow in Sim::OPT::Descend.\n";
 	say TOSHELL "\n#Now in Sim::OPT::Descend.\n";
@@ -82,9 +81,7 @@ sub descend
 	#say TOSHELL "dump(\$repfile): " . dump($repfile); 
 	%dowhat = %main::dowhat;
 
-	@themereports = @main::themereports; #say "dumpINDESCEND(\@themereports): " . dump(@themereports);
 	@simtitles = @main::simtitles; #say "dumpINDESCEND(\@simtitles): " . dump(@simtitles);
-	@reporttitles = @main::reporttitles;
 	@simdata = @main::simdata;
 	@retrievedata = @main::retrievedata;
 	@keepcolumns = @main::keepcolumns;
@@ -95,9 +92,7 @@ sub descend
 	@varthemes_steps = @main::varthemes_steps;
 	@rankdata = @main::rankdata; # CUT ZZZ
 	@rankcolumn = @main::rankcolumn;
-	@reporttempsdata = @main::reporttempsdata;
-	@reportcomfortdata = @main::reportcomfortdata;
-	@reportradiationenteringdata = @main::reportradiationenteringdata;
+	$reportdata = $main::reportdata;
 	@report_loadsortemps = @main::report_loadsortemps;
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
@@ -191,10 +186,10 @@ sub descend
 	{ # CLEANS THE MIXED FILE AND SELECTS SOME COLUMNS AND COPIES THEM IN ANOTHER FILE
 		say "Cleaning results for case $countcaseplus, block $contblocksplus.";
 		say TOSHELL "#Cleaning results for case $countcaseplus, block $contblocksplus.";
-		open ( MIXFILE, $repfile ) or die; #say TOSHELL "dump(\$repfile): " . dump($repfile); 
+		open( MIXFILE, $repfile ) or die; #say TOSHELL "dump(\$repfile): " . dump($repfile); 
 		my @lines = <MIXFILE>; #say TOSHELL "dump(MIXFILE \@lines): " . dump(@lines); 
 		close MIXFILE;
-		open ( CLEANMIXED, ">$cleanfile"); # or die;
+		open( CLEANMIXED, ">$cleanfile"); # or die;
 		foreach my $line (@lines)
 		{
 			$line =~ s/\n/°/g;
@@ -206,10 +201,10 @@ sub descend
 		# END. CLEANS THE MIXED FILE
 	
 		#SELECTS SOME COLUMNS AND COPIES THEM IN ANOTHER FILE
-		open (CLEANMIXED, $cleanfile); # or die;
+		open(CLEANMIXED, $cleanfile); # or die;
 		my @lines = <CLEANMIXED>; #say TOSHELL "dump(CLEANMIXED \@lines): " . dump(@lines); 
 		close CLEANMIXED;
-		open (SELECTEDMIXED, ">$selectmixed") or die;
+		open(SELECTEDMIXED, ">$selectmixed") or die;
 		
 		
 		foreach my $line (@lines)
@@ -255,11 +250,11 @@ sub descend
 	{
 		say "Scaling results for case $countcaseplus, block $contblocksplus.";
 		say TOSHELL "#Scaling results for case $countcaseplus, block $contblocksplus.";
-		open (SELECTEDMIXED, $selectmixed) or die; #say TOSHELL "dump(\$selectmixed): " . dump($selectmixed);
+		open(SELECTEDMIXED, $selectmixed) or die; #say TOSHELL "dump(\$selectmixed): " . dump($selectmixed);
 		my @lines = <SELECTEDMIXED>; #say TOSHELL "dump(SELECTEDMIXED \@lines): " . dump(@lines); 
 		close SELECTEDMIXED;
 		my $counterline = 0;
-		open (WEIGHT, ">$weight"); # or die;
+		open(WEIGHT, ">$weight"); # or die;
 		
 		my @containerone;
 		my @containernames;
@@ -390,10 +385,10 @@ sub descend
 	{
 		say "Weighting results for case $countcaseplus, block $contblocksplus.";
 		say TOSHELL "#Weighting results for case $countcaseplus, block $contblocksplus.";
-		open (WEIGHT, $weight); #say TOSHELL "dump(\$weight): " . dump($weight);
+		open(WEIGHT, $weight); #say TOSHELL "dump(\$weight): " . dump($weight);
 		my @lines = <WEIGHT>;
 		close WEIGHT;
-		open (WEIGHTTWO, ">$weighttwo"); #say TOSHELL "dump(\$weighttwo): " . dump($weighttwo);
+		open(WEIGHTTWO, ">$weighttwo"); #say TOSHELL "dump(\$weighttwo): " . dump($weighttwo);
 		my $counterline;
 		foreach my $line (@lines)
 		{
@@ -444,8 +439,8 @@ sub descend
 	{
 		say "Processing results for case $countcaseplus, block $contblocksplus.";
 		say TOSHELL "#Processing results for case $countcaseplus, block $contblocksplus.";
-		open (WEIGHTTWO, $weighttwo)or die; #say TOSHELL "dump(\$weighttwo): " . dump($weighttwo);
-		open (SORTMIXED_, ">$sortmixed") or die; #say TOSHELL "dump(\$sortmixed): " . dump($sortmixed);
+		open( WEIGHTTWO, $weighttwo ) or die; #say TOSHELL "dump(\$weighttwo): " . dump($weighttwo);
+		open(SORTMIXED_, ">$sortmixed") or die; #say TOSHELL "dump(\$sortmixed): " . dump($sortmixed);
 		my @lines = <WEIGHTTWO>;
 		close WEIGHTTWO;
 		my $count = 0;
@@ -495,7 +490,7 @@ sub descend
 		#say TOSHELL `cat $sortmixed`;
 		#say TOSHELL "TAKEOPTIMA cat \$sortmixed: $sortmixed";
 		
-		open (SORTMIXED_, $sortmixed); # or die;
+		open(SORTMIXED_, $sortmixed); # or die;
 		my @lines = <SORTMIXED_>;
 		close SORTMIXED_;
 		
@@ -508,7 +503,7 @@ sub descend
 		push ( @{ $uplift[$countcase][$countblock] }, $winnerval); #say TOSHELL "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
 		
 		my $cntelm = 0;
-		open ( MESSAGE, ">>$mypath/attention.txt");
+		open( MESSAGE, ">>$mypath/attention.txt");
 		foreach my $elm (@lines)
 		{
 			my @lineelms = split( /\s+|,/, $elm );
@@ -569,7 +564,7 @@ sub descend
 			#say $tee "#Gross number of instances: $instnum." ;
 			my $netinstnum = scalar(@morphcases);
 			say $tee "#Net number of instances: $netinstnum." ;
-			open( RESPONSE , ">$mypath/response.txt");
+			open( RESPONSE , ">$mypath/response.txt" );
 			say RESPONSE "#Optimal option for case  $countcaseplus: $newtarget";
 			#say RESPONSE "#Gross number of instances: $instnum." ;
 			say RESPONSE "#Net number of instances: $netinstnum." ;
@@ -584,6 +579,7 @@ sub descend
 		else
 		{
 			push ( @{ $winneritems[$countcase][$countblock] }, $newtarget); #say TOSHELL "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
+			"#Leaving case " . ($countcase + 1) . ", block " . ($countblock + 1) . " and descending!\ ";
 			Sim::OPT::callcase( { countcase => $countcase, countblock => $countblock, 
 			miditers => \@miditers,  winneritems => \@winneritems, 
 			dirfiles => \%dirfiles, uplift => \@uplift } );
