@@ -38,11 +38,11 @@ no warnings;
 
 @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
 #%EXPORT_TAGS = ( DEFAULT => [qw( &opt &prepare )]); # our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
-#@EXPORT_OK   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+#@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.40.0'; # our $VERSION = '';
+$VERSION = '0.41._0'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -86,16 +86,14 @@ sub sim    # This function launch the simulations in ESP-r
 	
 	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
 	
-	open ( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-	open ( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
+	open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
+	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
 	say  "\nNow in Sim::OPT::Sim.\n";
 	say TOSHELL "\n#Now in Sim::OPT::Sim.\n";
 	
 	%dowhat = %main::dowhat;
 
-	@themereports = @main::themereports; #say "dumpINSIM(\@themereports): " . dump(@themereports);
 	@simtitles = @main::simtitles; #say "dumpINSIM(\@simtitles): " . dump(@simtitles);
-	@reporttitles = @main::reporttitles;
 	@simdata = @main::simdata;
 	@retrievedata = @main::retrievedata;
 	@keepcolumns = @main::keepcolumns;
@@ -106,10 +104,7 @@ sub sim    # This function launch the simulations in ESP-r
 	@varthemes_steps = @main::varthemes_steps;
 	@rankdata = @main::rankdata; # CUT ZZZ
 	@rankcolumn = @main::rankcolumn;
-	@reporttempsdata = @main::reporttempsdata;
-	@reportcomfortdata = @main::reportcomfortdata;
-	@reportradiationenteringdata = @main::reportradiationenteringdata;
-	@report_loadsortemps = @main::report_loadsortemps;
+	$reportdata = $main::reportdata;
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
 	@base_columns = @main::base_columns;
@@ -203,11 +198,11 @@ sub sim    # This function launch the simulations in ESP-r
 			#{
 			#	if ( $countblock == 0 )
 			#	{
-					open ( SIMLIST, ">>$simlist") or die;
+					open( SIMLIST, ">>$simlist") or die;
 			#	}
 			#	else 
 			#	{
-			#		open ( SIMLIST, ">>$simlist") or die;
+			#		open( SIMLIST, ">>$simlist") or die;
 			#	}
 			#}
 			
@@ -216,11 +211,11 @@ sub sim    # This function launch the simulations in ESP-r
 			{
 				if ( $countblock == 0 )
 				{
-					open ( SIMBLOCK, ">>$simblock"); # or die;
+					open( SIMBLOCK, ">>$simblock"); # or die;
 				}
 				else 
 				{
-					open ( SIMBLOCK, ">>$simblock"); # or die;
+					open( SIMBLOCK, ">>$simblock"); # or die;
 				}
 			}
 			
@@ -237,53 +232,17 @@ sub sim    # This function launch the simulations in ESP-r
 			push ( @{ $simstruct[$countcase][$countblock] }, $resfile );
 			print SIMBLOCK "$resfile\n";
 			
-			if ( not ( $resfile ~~ @simcases ) )
+			if ( ( not ( $resfile ~~ @simcases ) ) and ( not ( -e $resfile ) ) )
 			{
 				push ( @simcases, $resfile );
 				print SIMLIST "$resfile\n";
 					
 				unless ( $preventsim eq "y" )
 				{
-					if ( not ( -e $resfile ) ) 
+					if ( $simnetwork eq "y" )
 					{
-						if ( $simnetwork eq "n" )
-						{
-							my $printthis =
-"bps -file $simelt/cfg/$fileconfig -mode script<<XXX
-
-c
-$resfile
-$simdata[0 + (4*$countsim)]
-$simdata[1 + (4*$countsim)]
-$simdata[2 + (4*$countsim)]
-$simdata[3 + (4*$countsim)]
-s
-$simnetwork
-Results for $simelt-$date_to_sim
-y
-y
--
--
--
--
--
--
--
-XXX
-";
-							if ($exeonfiles eq "y") 
-							{
-								print `$printthis`;
-							}
-							print TOSHELL "  
-#Simulating zones for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.
-$printthis
-";
-						}
-					
-						if ( $simnetwork eq "y" )
-						{
-							my $printthis =
+						say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $resfile and $flfile. " ;
+						my $printthis =	
 "bps -file $simelt/cfg/$fileconfig -mode script<<XXX
 
 c
@@ -307,17 +266,50 @@ y
 -
 XXX
 ";
-							if ($exeonfiles eq "y") 
-							{
-								print `$printthis`;
-							}
-							print TOSHELL " 
-#Simulating zones for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.\
+						if ($exeonfiles eq "y") 
+						{
+							print `$printthis`;
+						}
+						print TOSHELL " 	
+#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.\
 $printthis
 \n";
-							print OUTFILE "TWO, $resfile\n";
-						}						
-					}
+						print OUTFILE "TWO, $resfile\n";
+					}	
+					else # THAT IS: if ( $simnetwork eq "n" )
+					{
+						say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $resfile. " ;
+						my $printthis =
+"bps -file $simelt/cfg/$fileconfig -mode script<<XXX
+
+c
+$resfile
+$simdata[0 + (4*$countsim)]
+$simdata[1 + (4*$countsim)]
+$simdata[2 + (4*$countsim)]
+$simdata[3 + (4*$countsim)]
+s
+$simnetwork
+Results for $simelt-$date_to_sim
+y
+y
+-
+-
+-
+-
+-
+-
+-
+XXX
+";
+						if ($exeonfiles eq "y") 
+						{
+							print `$printthis`;
+						}
+						print TOSHELL "  
+$printthis
+";
+					}					
 				}		
 			}
 			$countsim++;
